@@ -1,8 +1,8 @@
 #include "plugin.h"
-#include "../src/authenticationrequest.h"
-#include "../src/resourcesmodel.h"
-#include "../src/streamsmodel.h"
-#include "../src/subtitlesmodel.h"
+#include "authenticationrequest.h"
+#include "resourcesmodel.h"
+#include "streamsmodel.h"
+#include "subtitlesmodel.h"
 #if QT_VERSION >= 0x050000
 #include <qqml.h>
 #else
