@@ -16,25 +16,18 @@
 
 #include "authenticationrequest.h"
 #include <QCoreApplication>
-#include <QStringList>
-#include <QDebug>
+#include <QSettings>
 
 int main(int argc, char *argv[]) {
     QCoreApplication app(argc, argv);
     app.setOrganizationName("QYouTube");
     app.setApplicationName("QYouTube");
+
+    QSettings settings;
     
-    QStringList args = app.arguments();
-    
-    if (args.size() < 2) {
-        qWarning() << "Usage: authentication-revoke TOKEN";
-        return 0;
-    }
-    
-    args.removeFirst();
-        
     QYouTube::AuthenticationRequest request;
-    request.revokeAccessToken(args.takeFirst());
+    request.setAccessToken(settings.value("Authentication/accessToken").toString());
+    request.revokeAccessToken();
     QObject::connect(&request, SIGNAL(finished()), &app, SLOT(quit()));
 
     return app.exec();
